Command-line generator in python
================================

.. image:: https://img.shields.io/pypi/l/clg.svg
           :target: https://opensource.org/licenses/MIT
           :alt: License

.. image:: https://img.shields.io/pypi/pyversions/clg.svg
           :target: https://pypi.python.org/pypi/clg
           :alt: Versions

.. image:: https://img.shields.io/pypi/v/clg.svg
           :target: https://pypi.python.org/pypi/clg
           :alt: PyPi

.. image:: https://img.shields.io/badge/github-repo-yellow.jpg
           :target: https://github.com/fmenabe/python-clg
           :alt: Code repo

.. image:: https://readthedocs.org/projects/clg/badge/?version=latest
           :target: http://clg.readthedocs.org/en/latest/
           :alt: Documentation

.. image:: https://landscape.io/github/fmenabe/python-clg/master/landscape.svg?style=flat
           :target: https://landscape.io/github/fmenabe/python-clg/master
           :alt: Code Health

.. .. image:: https://img.shields.io/pypi/dm/clg.svg
           :target: https://pypi.python.org/pypi/clg
           :alt: Downloads

This module, which wrap `argparse
<https://docs.python.org/3/library/argparse.html>`__, aims to simplify the
creation and the maintainabilty of command-line by defining its configuration
in a predefined struture (ie. a dictionnary). As python dictionnaries are easily
exportable to configuration files like *YAML* or *JSON*, the idea is to
outsource the command-line definition to a file instead of writing dozens or
hundreds lines of code.

* Code is available on `Github <http://github.com/fmenabe/python-clg>`__.
* Documentation is available on `Readthedocs <https://clg.readthedocs.org/en/latest/>`__.
* Changlog is available `here <http://github.com/fmenabe/python-clg/blob/master/CHANGELOG.rst>`__
